{% load cms_tags %}
{% spaceless %}
    {# djlint:off #}
    {% if instance.quote_origin %}
        <figure {{ instance.get_attributes }}>
        <blockquote class="blockquote">
    {% else %}
        <blockquote{{ instance.get_attributes }}>
    {% endif %}
    {# djlint:on #}
        {% for plugin in instance.child_plugin_instances %}
            {% with parentloop=forloop parent=instance %}{% render_plugin plugin %}{% endwith %}
        {% empty %}{{ instance.quote_content }}{% endfor %}
    {# djlint:off #}
    </blockquote>
    {# djlint:on #}
    {% if instance.quote_origin %}
        <figcaption class="blockquote-footer">
            <cite title="{{ instance.quote_origin }}">{{ instance.quote_origin }}</cite>
        </figcaption>
        </figure>
    {% endif %}
{% endspaceless %}
